use Test::More;

print STDERR "\nThis test requires internet access. Proceed ? ";

my $answer = readline(STDIN);

chop $answer;
if ( $answer ne 'y' && $answer ne 'yes' ) {
	plan skip_all, 'No Internet access'
}
else {
	plan tests => 8;
}

my $module = 'Net::DelCheck';

use_ok( $module );
 
my $checker = $module->new( { 'ModuleTemplatePath' => 'sample/template.xml' } );

isa_ok( $checker, 'Net::DelCheck' );

ok(  &Net::DelCheck::errors == 0, 'No errors in error array' );

my @roots;
foreach my $let qw( a b c d e f g h i j k l m ) {
	push @roots, $let.'.root-servers.net'
}

my @errors = $checker->get_data( '.',  @roots );

ok( @errors == 0, 'No errors after &get_data' );

my $xml_out = $checker->check;

$checker->cleanup;

my $parser = new XML::DOM::Parser;
        
# Parse into DOM doc
            
my $doc;
eval {
            $doc = $parser->parse( $xml_out );
};
        
ok( ! $@, 'XML output parses OK' );

my $root_elem = $doc->getDocumentElement();

ok( defined $root_elem, 'Root element defined' );


my $entity_tag_name = $checker->xml_tag_name( 'problem_entity' );
my $problem_tag_name = $checker->xml_tag_name( 'problem' );
my $problem_attribute_name = $checker->xml_attribute_name( 'problem_code' );

my ( $found_codes_flag, $unexpected_codes_flag ) = ( 0, 0 );

foreach my $entity_node ( $root_elem->getElementsByTagName( $entity_tag_name, 0 ) ) {
	foreach my $pcode ( $entity_node->getElementsByTagName( $problem_tag_name, 0 ) ) {
		$found_codes_flag = 1;
		my $pcode_attr_node = $pcode->getAttributeNode( $problem_attribute_name );
		my $value = $pcode_attr_node->getValue;

		if ( 
			( $value ne 'PROBLEM_SKIPPED_SERIAL_NUMBER' ) &&
			( $value ne 'PROBLEM_EXPIRE_OUT_OF_RANGE' ) &&
			( $value ne 'PROBLEM_SERIAL_NUMBERS_DIFFER' ) &&
			( $value ne 'PROBLEM_WRONG_REVERSE_MAPPING' )
		) {
			$unexpected_codes_flag = 1;
		}
	}
}

ok( $found_codes_flag, 'Found some codes' );
ok( $unexpected_codes_flag == 0, 'Unexpected problem codes' );
