#!/bin/bash

# Lee 20040128
# Setup a test case dir with default files
# The default files do not trigger any problem codes
# If <TESTNAME> has a .d suffix ('disabled'), the files created
# are all lined from the directory of the same name
# without the .d suffix, except output.conf which
# is created empty. The intention is to run exactly
# the same test but with the relevant check disabled.

# Usage: maketest.sh <TESTNAME>

testname=$1

enabledname=`basename $testname .d`

if [ $enabledname != $testname ]; then
    linkbase=../$enabledname
    herebase=../base
    if [ ! -d $enabledname ]; then
	echo "no directory $enabledname"
	exit 1
    fi
    disabled_dir=1
else
    linkbase=../../base
    copybase=../base
    herebase=../base
    disabled_dir=0
fi

echo "BASE: $linkbase"
echo "NEW: $testname"

if [ $testname == "" ]; then
	echo "Need a test name"
	exit -1
fi

if [ -f maketest.sh ]; then
	echo "Need to be in a problem code dir first"
	exit 1
fi

if [ -d base ]; then
	echo "Need to be in a problem code dir first"
	exit 1
fi

if [ -d $testname ]; then
	echo "Test dir already exists, exiting"
	exit 1
fi

if ! mkdir $testname; then
	echo "Couldnt make directory '$testname', exiting"
	exit 1
fi


ln -s $linkbase/resolver.xml $testname/resolver.xml

if [ $disabled_dir == "1" ]; then
    ln -s $linkbase/delcheck.0.conf $testname/delcheck.0.conf

    if [ -e $herebase/server.ns1.testzone.local:9001.xml ]; then
	ln -s $linkbase/server.ns1.testzone.local:9001.xml $testname/server.ns1.testzone.local:9001.xml
    elif [ -e $herebase/server-v6.ns1.testzone.local:9001.xml ]; then
	ln -s $linkbase/server-v6.ns1.testzone.local:9001.xml $testname/server-v6.ns1.testzone.local:9001.xml
    fi

    ln -s $linkbase/runtest.t $testname/runtest.t
else
    ln -s $linkbase/delcheck.conf $testname/delcheck.0.conf
    ln -s $linkbase/test.sh $testname/runtest.t 
    cp $copybase/server.ns1.testzone.local:9001.xml $testname/
fi

if [ -e $herebase/server.ns2.testzone.local:9002.xml ]; then
    ln -s $linkbase/server.ns2.testzone.local:9002.xml $testname/server.ns2.testzone.local:9002.xml
fi

if [ -e $herebase/server.ns3.testzone.local:9003.xml ]; then
    ln -s $linkbase/server.ns3.testzone.local:9003.xml $testname/server.ns3.testzone.local:9003.xml
fi

touch $testname/output.conf

echo Success!
ls -lR $testname
